.. _all-salt.tops:

===================
master tops modules
===================

.. currentmodule:: salt.tops

.. autosummary::
    :toctree:
    :template: autosummary.rst.tmpl

    cobbler
    ext_nodes
    mongo
    reclass_adapter
    varstack
